(function() {
    'use strict';

    const translations = {
        "Your last email was read": " המייל האחרון שלך נקרא ",
        "read your email": " קרא את המייל שלך ",
        "hours ago": " לפני שעות ",
        "Hasn't read your last email yet": " עדיין לא קרא את המייל האחרון שלך ",
        "Email not tracked": " מייל לא במעקב ",
        "read your last email": " קרא את המייל האחרון שלך ",
        "day ago": " לפני יום ",
        "days ago": " לפני ימים ",
        "times": " פעמים ",
        "First read": " קריאה ראשונה ",
        "day after you sent it": " יום אחרי ששלחת אותו ",
        "days after you sent it": " ימים אחרי ששלחת אותו ",
        "The open status of this message may be unreliable": " סטטוס הפתיחה של הודעה זו עשוי להיות לא אמין ",
        "It's possible that email service provider doesn't allow email tracking": " ייתכן שספק שירותי הדוא\"ל לא מאפשר מעקב אחר דוא\"ל ",
        "The open status of this message may be unreliable. It's possible that email service provider doesn't allow email tracking": " סטטוס הפתיחה של הודעה זו עשוי להיות לא אמין. ייתכן שספק שירותי הדוא\"ל לא מאפשר מעקב אחר דוא\"ל ",
        "minutes after you sent it": " דקות אחרי ששלחת אותו ",
        "First read hours after you sent it": " קריאה ראשונה שעות אחרי ששלחת אותו ",
        "First read less than a minute after you sent it": " קריאה ראשונה פחות מדקה אחרי ששלחת אותו ",
        "minutes ago": " לפני דקות "
    };

    function translateText(text) {
        let translated = text;
        for (let pattern in translations) {
            const regex = new RegExp(pattern, 'gi');
            translated = translated.replace(regex, translations[pattern]);
        }
        return translated;
    }

    function processTextNodes(element) {
        element.childNodes.forEach(node => {
            if (node.nodeType === Node.TEXT_NODE) {
                const text = node.textContent.trim();
                if (text && text !== "See full tracking history") {
                    const translated = translateText(text);
                    if (translated !== text) {
                        node.textContent = translated;
                    }
                }
            } else if (node.nodeType === Node.ELEMENT_NODE) {
                processTextNodes(node);
            }
        });
    }

    function updateTooltips() {
        document.querySelectorAll('[role="tooltip"]').forEach(tooltip => {
            const textOnly = tooltip.textContent.trim();
            if (textOnly && textOnly !== "See full tracking history") {
                const translatedText = translateText(textOnly);
                if (translatedText !== textOnly) {
                    if (textOnly in translations) {
                        tooltip.textContent = translatedText;
                    } else {
                        processTextNodes(tooltip);
                    }
                }
            }
        });
    }

    const observer = new MutationObserver(() => {
        updateTooltips();
    });

    observer.observe(document.body, { childList: true, subtree: true });

    updateTooltips();

    setInterval(() => {
        updateTooltips();
    }, 1000);
})();